@@ -6,7 +6,7 @@ from six.moves import queue
 
 from hackle import logger as _logging
 from hackle.event.event_dispatcher import EventDispatcher
-from .event import (BaseEvent, ExposureEvent, TrackEvent)
+from hackle.event.user_event import (UserEvent, ExposureEvent, TrackEvent)
 
 
 class BatchEventProcessor(object):
@@ -58,7 +58,7 @@ class BatchEventProcessor(object):
                 if self._get_time() >= self.flushing_interval_deadline:
                     self._flush_batch()
                     self.flushing_interval_deadline = self._get_time() + \
-                        self._get_time(self.flush_interval.total_seconds())
+                                                      self._get_time(self.flush_interval.total_seconds())
                     self.logger.debug('Flush interval deadline. Flushed batch.')
 
                 try:
@@ -80,7 +80,7 @@ class BatchEventProcessor(object):
                     self._flush_batch()
                     continue
 
-                if isinstance(item, BaseEvent):
+                if isinstance(item, UserEvent):
                     self._add_to_batch(item)
 
         except Exception as exception:
